@@ -19,6 +19,7 @@ import argparse
 import configparser
 import re
 import sys
+from copy import deepcopy
 from os import makedirs, remove
 from os.path import dirname, exists, expanduser, join
 from random import randint
@@ -110,6 +111,10 @@ def main():
     if args.pre:
         args.parse_mode = "markdown"
 
+    if args.parse_mode == "markdown":
+        # Use the improved MarkdownV2 format by default
+        args.parse_mode = telegram.constants.PARSEMODE_MARKDOWN_V2
+
     if args.stdin:
         message = sys.stdin.read()
         if len(message) == 0:
@@ -122,7 +127,8 @@ def main():
                 conf=c,
                 parse_mode=args.parse_mode,
                 silent=args.silent,
-                disable_web_page_preview=args.disable_web_page_preview
+                disable_web_page_preview=args.disable_web_page_preview,
+                timeout=args.timeout,
             )
 
     try:
@@ -210,8 +216,7 @@ def send(*,
     settings = get_config_settings(conf)
     token = settings.token
     chat_id = settings.chat_id
-    request = telegram.utils.request.Request(read_timeout=timeout)
-    bot = telegram.Bot(token, request=request)
+    bot = telegram.Bot(token)
 
     # We let the user specify "text" as a parse mode to be more explicit about
     # the lack of formatting applied to the message, but "text" isn't a supported
@@ -220,17 +225,22 @@ def send(*,
     if parse_mode == "text":
         parse_mode = None
 
-    # collect all message ids sent during the current invokation
+    # collect all message ids sent during the current invocation
     message_ids = []
 
+    kwargs = {
+        "chat_id": chat_id,
+        "disable_notification": silent,
+        "timeout": timeout,
+    }
+
     if messages:
         def send_message(message):
             return bot.send_message(
-                chat_id=chat_id,
                 text=message,
                 parse_mode=parse_mode,
-                disable_notification=silent,
-                disable_web_page_preview=disable_web_page_preview
+                disable_web_page_preview=disable_web_page_preview,
+                **kwargs
             )
 
         for m in messages:
@@ -251,52 +261,53 @@ def send(*,
         captions += [None] * (len(items) - len(captions))
         return zip(items, captions)
 
+    # kwargs for send methods with caption support
+    kwargs_caption = deepcopy(kwargs)
+    kwargs_caption["parse_mode"] = parse_mode
+
     if files:
         if captions:
             for (f, c) in make_captions(files, captions):
-                message_ids += [bot.send_document(chat_id=chat_id, document=f, caption=c, disable_notification=silent)]
+                message_ids += [bot.send_document(document=f, caption=c, **kwargs_caption)]
         else:
             for f in files:
-                message_ids += [bot.send_document(chat_id=chat_id, document=f, disable_notification=silent)]
+                message_ids += [bot.send_document(document=f, **kwargs)]
 
     if images:
         if captions:
             for (i, c) in make_captions(images, captions):
-                message_ids += [bot.send_photo(chat_id=chat_id, photo=i, caption=c, disable_notification=silent)]
+                message_ids += [bot.send_photo(photo=i, caption=c, **kwargs_caption)]
         else:
             for i in images:
-                message_ids += [bot.send_photo(chat_id=chat_id, photo=i, disable_notification=silent)]
+                message_ids += [bot.send_photo(photo=i, **kwargs)]
 
     if stickers:
         for i in stickers:
-            message_ids += [bot.send_sticker(chat_id=chat_id, sticker=i, disable_notification=silent)]
+            message_ids += [bot.send_sticker(sticker=i, **kwargs)]
 
     if animations:
         if captions:
             for (a, c) in make_captions(animations, captions):
-                message_ids += [bot.send_animation(chat_id=chat_id,
-                                                   animation=a,
-                                                   caption=c,
-                                                   disable_notification=silent)]
+                message_ids += [bot.send_animation(animation=a, caption=c, **kwargs_caption)]
         else:
             for a in animations:
-                message_ids += [bot.send_animation(chat_id=chat_id, animation=a, disable_notification=silent)]
+                message_ids += [bot.send_animation(animation=a, **kwargs)]
 
     if videos:
         if captions:
             for (v, c) in make_captions(videos, captions):
-                message_ids += [bot.send_video(chat_id=chat_id, video=v, caption=c, disable_notification=silent)]
+                message_ids += [bot.send_video(video=v, caption=c, **kwargs_caption)]
         else:
             for v in videos:
-                message_ids += [bot.send_video(chat_id=chat_id, video=v, disable_notification=silent)]
+                message_ids += [bot.send_video(video=v, **kwargs)]
 
     if audios:
         if captions:
             for (a, c) in make_captions(audios, captions):
-                message_ids += [bot.send_audio(chat_id=chat_id, audio=a, caption=c, disable_notification=silent)]
+                message_ids += [bot.send_audio(audio=a, caption=c, **kwargs_caption)]
         else:
             for a in audios:
-                message_ids += [bot.send_audio(chat_id=chat_id, audio=a, disable_notification=silent)]
+                message_ids += [bot.send_audio(audio=a, **kwargs)]
 
     if locations:
         it = iter(locations)
@@ -306,10 +317,9 @@ def send(*,
             else:
                 lat = loc
                 lon = next(it)
-            message_ids += [bot.send_location(chat_id=chat_id,
-                                              latitude=float(lat),
+            message_ids += [bot.send_location(latitude=float(lat),
                                               longitude=float(lon),
-                                              disable_notification=silent)]
+                                              **kwargs)]
 
     return message_ids
 
@@ -330,8 +340,7 @@ def delete(message_ids, conf=None, timeout=30):
     settings = get_config_settings(conf)
     token = settings.token
     chat_id = settings.chat_id
-    request = telegram.utils.request.Request(read_timeout=timeout)
-    bot = telegram.Bot(token, request=request)
+    bot = telegram.Bot(token)
 
     if message_ids:
         for m in message_ids:
@@ -391,7 +400,7 @@ def configure(conf, channel=False, group=False, fm_integration=False):
             print("\nOpen https://web.telegram.org in your browser, sign in and open your private channel."
                   "\nNow copy the URL in the address bar and enter it here:")
             url = input(markup(prompt, "magenta")).strip()
-            chat_id = "-100" + re.match(r".+web\.telegram\.org\/#\/im\?p=c(\d+)", url).group(1)
+            chat_id = "-100" + re.match(r".+web\.(telegram|tlgr)\.org\/#\/im\?p=c(\d+)", url).group(2)
 
         authorized = False
         while not authorized:
